@@ -1,7 +1,6 @@
 ;;; sb-bbdb-ml.el --- shimbun backend for bbdb-ml
 
-;; Author: TSUCHIYA Masatoshi <tsuchiya@pine.kuee.kyoto-u.ac.jp>
-;;         Akihiro Arisawa    <ari@atesoft.advantest.co.jp>
+;; Author: Akihiro Arisawa   <ari@mbf.sphere.ne.jp>,
 ;;         Yuuichi Teranishi <teranisi@gohome.org>
 
 ;; Keywords: news
@@ -26,7 +25,7 @@
 ;;; Commentary:
 
 ;; Original code was nnshimbun.el written by
-;; TSUCHIYA Masatoshi <tsuchiya@pine.kuee.kyoto-u.ac.jp>.
+;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>.
 
 ;;; Code:
 
@@ -37,7 +36,6 @@
 
 (defvar shimbun-bbdb-ml-url "http://www.rc.tutrp.tut.ac.jp/bbdb-ml/")
 (defvar shimbun-bbdb-ml-groups '("bbdb-ml"))
-(defvar shimbun-bbdb-ml-coding-system 'iso-2022-jp)
 
 (provide 'sb-bbdb-ml)
 
